@@ -7,8 +7,12 @@ class DefaultHandler:
     guild = None
     guild_member = None
     channel = None
-    message = None
+    message_create = None
+    message_delete = None
     at_message = None
-    direct_message = None
+    public_message_delete = None
+    direct_message_create = None
+    direct_message_delete = None
     audio = None
     message_reaction = None
+    interaction_create = None
