@@ -70,23 +70,41 @@ def channel_event_handler(callback, intent):
 
 
 def message_event_handler(callback, intent):
-    DefaultHandler.message = callback
+    DefaultHandler.message_create = callback
     intent = intent | WsEvent.event_to_intent(WsEvent.EventMessageCreate)
     return intent
 
 
+def delete_message_event_handler(callback, intent):
+    DefaultHandler.message_delete = callback
+    intent = intent | WsEvent.event_to_intent(WsEvent.EventMessageDelete)
+    return intent
+
+
 def at_message_event_handler(callback, intent):
     DefaultHandler.at_message = callback
     intent = intent | WsEvent.event_to_intent(WsEvent.EventAtMessageCreate)
     return intent
 
 
+def public_message_delete_event_handler(callback, intent):
+    DefaultHandler.public_message_delete = callback
+    intent = intent | WsEvent.event_to_intent(WsEvent.EventPublicMessageDelete)
+    return intent
+
+
 def direct_message_event_handler(callback, intent):
-    DefaultHandler.direct_message = callback
+    DefaultHandler.direct_message_create = callback
     intent = intent | WsEvent.event_to_intent(WsEvent.EventDirectMessageCreate)
     return intent
 
 
+def delete_direct_message_event_handler(callback, intent):
+    DefaultHandler.direct_message_delete = callback
+    intent = intent | WsEvent.event_to_intent(WsEvent.EventDirectMessageDelete)
+    return intent
+
+
 def message_reactions_event_handler(callback, intent):
     DefaultHandler.message_reaction = callback
     intent = intent | WsEvent.event_to_intent(
@@ -96,16 +114,28 @@ def message_reactions_event_handler(callback, intent):
     return intent
 
 
+def interaction_create_event_handler(callback, intent):
+    DefaultHandler.interaction_create = callback
+    intent = intent | WsEvent.event_to_intent(
+        WsEvent.EventInteractionCreate
+    )
+    return intent
+
+
 class HandlerType(Enum):
     PLAIN_EVENT_HANDLER = 0
     GUILD_EVENT_HANDLER = 1
     GUILD_MEMBER_EVENT_HANDLER = 2
     CHANNEL_EVENT_HANDLER = 3
     MESSAGE_EVENT_HANDLER = 4
-    AT_MESSAGE_EVENT_HANDLER = 5
-    DIRECT_MESSAGE_EVENT_HANDLER = 6
-    AUDIO_EVENT_HANDLER = 7
-    MESSAGE_REACTIONS_EVENT_HANDLER = 8
+    MESSAGE_DELETE_EVENT_HANDLER = 5
+    AT_MESSAGE_EVENT_HANDLER = 6
+    DIRECT_MESSAGE_EVENT_HANDLER = 7
+    DIRECT_MESSAGE_DELETE_EVENT_HANDLER = 8
+    AUDIO_EVENT_HANDLER = 9
+    MESSAGE_REACTIONS_EVENT_HANDLER = 10
+    PUBLIC_MESSAGE_DELETE_EVENT_HANDLER = 11
+    INTERACTION_CREATE_HANDLER = 12
 
 
 intent_handler_dict = {
@@ -114,8 +144,12 @@ intent_handler_dict = {
     HandlerType.GUILD_MEMBER_EVENT_HANDLER.value: guild_member_event_handler,
     HandlerType.CHANNEL_EVENT_HANDLER.value: channel_event_handler,
     HandlerType.MESSAGE_EVENT_HANDLER.value: message_event_handler,
+    HandlerType.MESSAGE_DELETE_EVENT_HANDLER.value: delete_message_event_handler,
     HandlerType.AT_MESSAGE_EVENT_HANDLER.value: at_message_event_handler,
+    HandlerType.PUBLIC_MESSAGE_DELETE_EVENT_HANDLER.value: public_message_delete_event_handler,
     HandlerType.DIRECT_MESSAGE_EVENT_HANDLER.value: direct_message_event_handler,
+    HandlerType.DIRECT_MESSAGE_DELETE_EVENT_HANDLER.value: delete_direct_message_event_handler,
     HandlerType.AUDIO_EVENT_HANDLER.value: audio_event_handler,
     HandlerType.MESSAGE_REACTIONS_EVENT_HANDLER.value: message_reactions_event_handler,
+    HandlerType.INTERACTION_CREATE_HANDLER.value: interaction_create_event_handler,
 }
