@@ -9,8 +9,9 @@ from qqbot.model.audio import AudioAction
 from qqbot.model.channel import Channel
 from qqbot.model.guild import Guild
 from qqbot.model.guild_member import GuildMember
-from qqbot.model.message import Message
+from qqbot.model.message import Message, DeletedMessageInfo
 from qqbot.model.reaction import Reaction
+from qqbot.model.interaction import Interaction
 
 logger = logging.getLogger()
 
@@ -63,22 +64,46 @@ def _handle_event_at_message_create(message_event, message):
     callback(message_event, at_message)
 
 
+def _handle_event_public_message_delete(message_event, message):
+    callback = DefaultHandler.public_message_delete
+    if callback is None:
+        return
+    message_deletion_info: DeletedMessageInfo = json.loads(_parse_data(message), object_hook=DeletedMessageInfo)
+    callback(message_event, message_deletion_info)
+
+
 def _handle_event_message_create(message_event, message):
-    callback = DefaultHandler.message
+    callback = DefaultHandler.message_create
     if callback is None:
         return
     msg: Message = json.loads(_parse_data(message), object_hook=Message)
     callback(message_event, msg)
 
 
+def _handle_event_message_delete(message_event, message):
+    callback = DefaultHandler.message_delete
+    if callback is None:
+        return
+    message_deletion_info: DeletedMessageInfo = json.loads(_parse_data(message), object_hook=DeletedMessageInfo)
+    callback(message_event, message_deletion_info)
+
+
 def _handle_event_direct_message_create(message_event, message):
-    callback = DefaultHandler.direct_message
+    callback = DefaultHandler.direct_message_create
     if callback is None:
         return
     msg: Message = json.loads(_parse_data(message), object_hook=Message)
     callback(message_event, msg)
 
 
+def _handle_event_direct_message_delete(message_event, message):
+    callback = DefaultHandler.direct_message_delete
+    if callback is None:
+        return
+    message_deletion_info: DeletedMessageInfo = json.loads(_parse_data(message), object_hook=DeletedMessageInfo)
+    callback(message_event, message_deletion_info)
+
+
 def _handle_event_audio(message_event, message):
     callback = DefaultHandler.audio
     if callback is None:
@@ -97,6 +122,14 @@ def _handle_event_message_reaction(message_event, message):
     callback(message_event, reaction)
 
 
+def _handle_event_interaction_create(message_event, message):
+    callback = DefaultHandler.interaction_create
+    if callback is None:
+        return
+    interaction: Interaction = json.loads(_parse_data(message), object_hook=Interaction)
+    callback(message_event, interaction)
+
+
 event_handler_dict = {
     WsEvent.EventGuildCreate: _handle_event_guild,
     WsEvent.EventGuildUpdate: _handle_event_guild,
@@ -108,14 +141,18 @@ event_handler_dict = {
     WsEvent.EventGuildMemberUpdate: _handle_event_guild_member,
     WsEvent.EventGuildMemberRemove: _handle_event_guild_member,
     WsEvent.EventAtMessageCreate: _handle_event_at_message_create,
+    WsEvent.EventPublicMessageDelete: _handle_event_public_message_delete,
     WsEvent.EventMessageCreate: _handle_event_message_create,
+    WsEvent.EventMessageDelete: _handle_event_message_delete,
     WsEvent.EventDirectMessageCreate: _handle_event_direct_message_create,
+    WsEvent.EventDirectMessageDelete: _handle_event_direct_message_delete,
     WsEvent.EventAudioStart: _handle_event_audio,
     WsEvent.EventAudioFinish: _handle_event_audio,
     WsEvent.EventAudioOnMic: _handle_event_audio,
     WsEvent.EventAudioOffMic: _handle_event_audio,
     WsEvent.EventMessageReactionAdd: _handle_event_message_reaction,
     WsEvent.EventMessageReactionRemove: _handle_event_message_reaction,
+    WsEvent.EventInteractionCreate: _handle_event_interaction_create,
 }
 
 
